@@ -5,7 +5,7 @@ from typing import Tuple, Sequence, Dict
 from converter import utils
 from zipfile import ZipFile
 from . import decodefig, vector_network
-from PIL import Image, UnidentifiedImageError
+from PIL import Image, UnidentifiedImageError, ImageFile
 
 
 def convert_fig(path: str, output: ZipFile) -> Tuple[dict, Dict[Sequence[int], dict]]:
@@ -119,8 +119,12 @@ def convert_image(fname, blob, fig_zip, output):
         converted_images[fname] = f"{fhash}{extension}"
         return f"{fhash}{extension}"
     except UnidentifiedImageError as e:
-        logging.critical(f"Could not convert image {fname}. It appears to be corrupted.")
-        logging.critical(
-            f"Try passing `--force-convert-images` to ignore this error and try to convert the image anyway."
-        )
-        exit(1)
+        if ImageFile.LOAD_TRUNCATED_IMAGES:
+            utils.log_conversion_warning("IMG002", {"type": "Image", "guid": fname, "name": fname})
+        else:
+            utils.log_conversion_warning("IMG001", {"type": "Image", "guid": fname, "name": fname})
+
+        return "f2s_corrupted"
+    except KeyError:
+        utils.log_conversion_warning("IMG003", {"type": "Image", "guid": fname, "name": fname})
+        return "f2s_missing"
